@@ -185,15 +185,18 @@ mi.info.params.default <-function( info ){
 # Default formula for the type
 # ========================================================================
 type.default.formula <- function(response.name, predictor.name, type) {
-#  if (type=="ordered-categorical"){
-#    form <- paste( paste( "ordered(", response.name, ") ~",sep=""),paste(predictor.name,collapse=" + "))
-#  } 
-#  else if (type=="fixed"){
-#    form <- paste( response.name, " ~",response.name)
-#  } 
-#  else{
+  if (type=="ordered-categorical"){
+    form <- paste( paste( "ordered(", response.name, ") ~",sep=""),paste(predictor.name,collapse=" + "))
+  } 
+  else if (type=="unordered-categorical"){
+    form <- paste( paste( "factor(", response.name, ") ~",sep=""),paste(predictor.name,collapse=" + "))
+  } 
+  else if (type=="fixed"){
+    form <- paste( response.name, " ~",response.name)
+  } 
+  else{
   form <- paste( response.name,"~",paste(predictor.name,collapse=" + "))
-  #}
+  }
   return(form)
 }
 
@@ -319,7 +322,9 @@ mi.info.fix <- function( info ) {
                   #type
                   res.var3.type <- menu(mi.types(),title="choose a type to change to")
                   print(res.var3.type)
-                  info[[Var.to.fix]]$type <- mi.types()[res.var3.type]
+                  change.list <- list(Var.to.fix=mi.types()[res.var3.type])
+                  names(change.list) <- Var.to.fix
+                  info <- update(info, target="type", change.list)
                   #type.default.formula(,info[[Var.to.fix]]$type)
                 }
                 else if(res.var3 ==2){
@@ -654,15 +659,14 @@ update.mi.info <- function(object, target, list, ...){
   for ( i in 1:length( list ) ) {
     object[[nam[i]]][[target]] <- list[[nam[i]]]
     if(target=="type"){
-      varnames <- names(object)
-      object$include[nam[i]] <- FALSE
-      inc <- object$include
-      varnames <- varnames[inc,drop=TRUE]
-      object[[nam[i]]]["imp.formula"] <- type.default.formula(
-                                          nam[i], 
-                                          varnames, 
-                                          object$type[nam[i]])
-      object$include[nam[i]] <- TRUE
+      if(object$type[nam[i]]=="ordered-categorical"){
+        object$imp.formula <- sapply(object$imp.formula, 
+          .change.formula.ordered, varnames=nam[i])
+      }
+      if(object$type[nam[i]]=="unordered-categorical"){
+        object$imp.formula <- sapply(object$imp.formula, 
+          .change.formula.unordered, varnames=nam[i])
+      }
     }
   }
   return(info=object)
